@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -24,6 +24,7 @@
 #endif
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 
 #include "gtrie.h"
@@ -377,6 +378,7 @@ url_web_end (const char *in, const char *pos, const char *inend, urlmatch_t *mat
 		} else if (*inptr == ':') {
 			/* IPv6 can start with a ':' */
 			end = (char *) inptr;
+			val = 256; /* invalid value */
 		} else {
 			return FALSE;
 		}
